[Scummvm-cvs-logs] CVS: scummvm/scumm scummvm.cpp,1.52,1.53

Max Horn fingolfin at users.sourceforge.net
Wed Oct 9 13:30:06 CEST 2002


Update of /cvsroot/scummvm/scummvm/scumm
In directory usw-pr-cvs1:/tmp/cvs-serv18347/scumm

Modified Files:
	scummvm.cpp 
Log Message:
in error() use g_system instead of g_scumm->_system in order to support Simon; also check if g_system already exists, otherwise just call exit(1)

Index: scummvm.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/scummvm.cpp,v
retrieving revision 1.52
retrieving revision 1.53
diff -u -d -r1.52 -r1.53
--- scummvm.cpp	8 Oct 2002 00:29:32 -0000	1.52
+++ scummvm.cpp	9 Oct 2002 20:29:26 -0000	1.53
@@ -1334,14 +1334,11 @@
 #endif
 	}
 	
-	// Finally exit. quit() will terminate the program
-	g_scumm->_system->quit();
-	
+	// Finally exit. quit() will terminate the program if g_system iss present
+	if (g_system)
+		g_system->quit();
 	
-	// This point should never be reached. However, since virtual methods (like quit() is)
-	// can't be marked as noreturn, gcc will complain at this point. Thus we add in this
-	// call to exit(0) even though it is never reached.
-	exit(0);
+	exit(1);
 }
 
 ScummDebugger g_debugger;





More information about the Scummvm-git-logs mailing list